psychopy_ext.exp.Task.create_stimuli — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.create_stimuli

`Task.` `create_stimuli`()

  Define stimuli as a dictionary

  Example:

      self.create_fixation(color='white')
      line1 = visual.Line(self.win, name='line1')
      line2 = visual.Line(self.win, fillColor='DarkRed')
      self.s = {
          'fix': self.fixation,
          'stim1': [visual.ImageStim(self.win, name='stim1')],
          'stim2': GroupStim(stimuli=[line1, line2], name='lines')
          }